@@ -39,7 +39,7 @@
 #include <string.h>
 #if !defined(WIN32) && !defined(_WIN32) && !defined(__WIN32) && !defined(__WIN32__)
 #include <strings.h> 
-#endif
+#endif /* WIN32 */
 #include <time.h>
 #include <sys/types.h>
 #include "pronpass.h"
